@@ -1,4 +1,4 @@
-from composio.client.enums import Action, App, Tag, Trigger
+from composio import Action, App, Tag, Trigger, WorkspaceType
 
 from composio_praisonai.toolset import ComposioToolSet
 
@@ -9,4 +9,5 @@ __all__ = (
     "Tag",
     "Trigger",
     "ComposioToolSet",
+    "WorkspaceType",
 )
